VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "PTSTEngine"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True

Option Explicit
Private mEngine As VMengine
Private mMappingFileName As String
' carridge return
Private LineBreak As String
Private mIsStrictGrammar As Boolean
Private mLoaded As Boolean

' This property contains a copy of the resulting Message object
' created by the ParseMessage method
Public ParsedMessage As Object
' Error Events
Public Event OnLoadError(FileName As String)
Public Event OnParseError(Code As Long, Description As String, MessageData As String, TreeView As String, ResultMessage As String)
Public Event OnGenerateError(Code As Long, Description As String)
' On Message - useful for logging messages
Public Event OnMessage(MessageData As String)
' Message handling events
' Begin message functions (comment used as an anchor by STVB6)
Public Event OnMessageADTA04(Message As PTSTMsgADTA04, ResultMessage As String)


Public Function NewADTA04() As PTSTMsgADTA04
   Set NewADTA04 = New PTSTMsgADTA04
   NewADTA04.Init Me
End Function
' End message functions (comment used as an anchor by STVB6)


Public Function Parse(FlatWire As String) As String
   On Error GoTo ErrorHandler
   RaiseEvent OnMessage(FlatWire)
   Dim MessageIndex As Long, ResultTable As IVMtable
   mEngine.Parse FlatWire, MessageIndex, ResultTable

   Select Case MessageIndex
' Begin message case statements (comment used as an anchor by STVB6)
   Case 0
   Dim Message0 As New PTSTMsgADTA04
   Set Message0.Engine = Me ' For Error Handling
   Set Message0.Table = ResultTable
   Set ParsedMessage = Message0
   RaiseEvent OnMessageADTA04(Message0, Parse)
   Set Message0 = Nothing

' End message case statements (comment used as an anchor by STVB6)
   Case Else
      Err.Description = "Warning unknown message index - Visual Basic ActiveX Control is out of date."
      Err.Raise 1
   End Select

   Exit Function
ErrorHandler:
   Parse = HandleParseError(FlatWire)
End Function

' Use this property to access an exploded tree view of the message 
' annotated with parsing errors
Public Property Get TreeErrorView() As String
   On Error Resume Next
   TreeErrorView = mEngine.ErrorTree
End Property

' Use this function to get a short label for an error code
Public Function ErrorLabel(Code As VMexceptionCode) As String
   On Error Resume Next
   ErrorLabel = mEngine.ExceptionLabel(Code)
End Function

Friend Property Get Engine() As VMengine
   On Error Resume Next
   Set Engine = mEngine
End Property

Public Property Get MappingFile() As String
   On Error Resume Next
   MappingFile = mMappingFileName
End Property

Public Function ExceptionLabel(Code As Long) As String
   ExceptionLabel = mEngine.ExceptionLabel(Code)
End Function

Public Function DefaultHeader() As String
   DefaultHeader = mEngine.Config.DefaultHeader
End Function

Public Sub HandleError()
   RaiseEvent OnGenerateError(Err.Number, Err.Description)
End Sub

Public Function HandleParseError(MessageData As String) As String
   HandleParseError = "NOTHANDLED"
   RaiseEvent OnParseError(Err.Number, Err.Description, MessageData, mEngine.ErrorTree, HandleParseError)
   If HandleParseError = "NOTHANDLED" Then
      Dim Description As String
      Description = ExceptionLabel(Err.Number) & LineBreak & Err.Description
      If Left(MessageData, Len(DefaultHeader)) <> DefaultHeader Then
         Description = Description & LineBreak & LineBreak & "Hint: The default message header would normally start like:" & LineBreak & DefaultHeader
      End If
      Description = Description & LineBreak & LineBreak & "Flatwire Message:" & LineBreak & MessageData
      Select Case Err.Number
         Case VMprBadMessageGrammar, VMprBadSegmentGrammar, VMprNoSegmentIdentifier, VMprUnknownMessage, VMprUnknownSegment
         Description = Description & LineBreak & "Exploded tree view of the message with errors:" & LineBreak & LineBreak
         Description = Description & mEngine.ErrorTree
      End Select
      Err.Description = Description
      Err.Raise 1
  End If
End Function

Private Sub HandleLoadError(FileName As String)
   RaiseEvent OnLoadError(FileName)
   Err.Description = "Failed to load the mapping file '" & FileName & "'"
   Err.Raise 1
End Sub

Public Sub Init()
   Set mEngine = New VMengine
End Sub

Public Sub Load(FileName As String)
   On Error GoTo ErrorHandler
   mMappingFileName = FileName
   mEngine.Load (FileName)
   mLoaded = True
   Exit Sub
ErrorHandler:
   HandleLoadError (FileName)
End Sub

Public Property Let StrictGrammarChecking(vData As Boolean)
   On Error Resume Next
   mIsStrictGrammar = vData
   Engine.RejectBadSegmentGrammar = vData
End Property

Public Property Get StrictGrammarChecking() As Boolean
   On Error Resume Next
   StrictGrammarChecking = mEngine.mIsStrictGrammar
End Property

Public Property Get InternalEngine() As IVMengine
   Set InternalEngine = mEngine
End Property

Private Sub Class_Initialize()
   Set mEngine = New VMengine
End Sub

Private Sub Class_Terminate()
   On Error Resume Next
   Set mEngine = Nothing
End Sub
